require 'spec_helper'

describe Mdm::ExploitAttempt do

  context 'associations' do
    it { should belong_to(:host).class_name('Mdm::Host') }
  end

  context 'database' do

    context 'timestamps'do
      it { should have_db_column(:attempted_at).of_type(:datetime) }
    end

    context 'columns' do
      it { should have_db_column(:host_id).of_type(:integer) }
      it { should have_db_column(:service_id).of_type(:integer) }
      it { should have_db_column(:vuln_id).of_type(:integer) }
      it { should have_db_column(:exploited).of_type(:boolean) }
      it { should have_db_column(:fail_reason).of_type(:string) }
      it { should have_db_column(:username).of_type(:string) }
      it { should have_db_column(:module).of_type(:text) }
      it { should have_db_column(:session_id).of_type(:integer) }
      it { should have_db_column(:loot_id).of_type(:integer) }
      it { should have_db_column(:port).of_type(:integer) }
      it { should have_db_column(:proto).of_type(:string) }
      it { should have_db_column(:fail_detail).of_type(:text) }
    end
  end

  context '#destroy' do
    it 'should successfully destroy the object and all dependent objects' do
      exploit_attempt = FactoryGirl.create(:mdm_exploit_attempt)
      expect {
        exploit_attempt.destroy
      }.to_not raise_error
      expect {
        exploit_attempt.reload
      }.to raise_error(ActiveRecord::RecordNotFound)

    end
  end

  context 'validations' do
    it 'should only be valid with a host_id' do
      orphaned_attempt = FactoryGirl.build(:mdm_exploit_attempt, :host => nil)
      orphaned_attempt.should_not be_valid
      orphaned_attempt.errors[:host_id].should include("can't be blank")
      propper_attempt = FactoryGirl.build(:mdm_exploit_attempt)
      propper_attempt.should be_valid
    end
  end

  context 'factory' do
    it 'should be valid' do
      exploit_attempt = FactoryGirl.build(:mdm_exploit_attempt)
      exploit_attempt.should be_valid
    end
  end
end